
#include <iostream>
#include <gtest/gtest.h>
#include <system_info.h>
#include "hw/battery.h"
#include "unittest.h"

using namespace std;

/*
 * main class
 */
struct hw_info *info;
struct battery_device *battery_dev;
static bool need_featurecheck = true;

class BATTERYHalTest : public testing::Test
{
	public:
		virtual void SetUp()
		{
			int ret;

			if (need_featurecheck) {
				ret = system_info_get_platform_bool(FEATURE_BATTERY, &supported);
				EXPECT_EQ(SYSTEM_INFO_ERROR_NONE, ret) << "system_info_get_platform_bool failed";
				need_featurecheck = false;
			}
		}

		virtual void TearDown()
		{

		}
};

/*
 * testcase
 */
TEST_F(BATTERYHalTest, InitP)
{
	int ret;

	if (!supported)
		return;

	ret = hw_get_info(BATTERY_HARDWARE_DEVICE_ID,
			(const struct hw_info **)&info);
	EXPECT_EQ(ret, 0) << "Fail to load battery hal (" << ret << ")";

	if (!info->open) {
		cout << "There is no function for info open" << endl;
		return;
	}
	ret = info->open(info, NULL, (struct hw_common**)&battery_dev);
	EXPECT_EQ(ret, 0) << "Fail to open battery device(" << ret << ")";
}

static void updated_cb(struct battery_info *info, void *data)
{

}

TEST_F(BATTERYHalTest, RegisterChangedEventP)
{
	int ret;

	if (!supported)
		return;

	if (!battery_dev->register_changed_event) {
		cout << "There is no function for register_changed_event" << endl;
		return;
	}
	ret = battery_dev->register_changed_event(updated_cb, NULL);
	EXPECT_EQ(ret, 0) << "Fail to register_changed_event (" << ret << ")";
}

TEST_F(BATTERYHalTest, UnregisterChangedEventP)
{
	if (!supported)
		return;

	if (!battery_dev->unregister_changed_event) {
		cout << "There is no function for unregister_changed_event" << endl;
		return;
	}
	battery_dev->unregister_changed_event(updated_cb);
}

TEST_F(BATTERYHalTest, GetCurrentStateP)
{
	int ret;

	if (!supported)
		return;

	if (!battery_dev->get_current_state) {
		cout << "There is no function for get_current_state" << endl;
		return;
	}
	ret = battery_dev->get_current_state(updated_cb, NULL);
	EXPECT_EQ(ret, 0) << "Fail to get_current_state (" << ret << ")";
}

TEST_F(BATTERYHalTest, DeinitP)
{
	int ret;

	if (!supported)
		return;

	if (!info->close) {
		cout << "There is no function for info close" << endl;
		return;
	}
	ret = info->close((struct hw_common *)battery_dev);
	EXPECT_EQ(ret, 0) << "Fail to close battery device(" << ret << ")";
}

int main(int argc, char **argv)
{
	testing::InitGoogleTest(&argc, argv);

	return RUN_ALL_TESTS();
}
